package com.sooka.system.service.impl;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import com.sooka.system.domain.SysDept;
import com.sooka.system.domain.SysMenu;
import com.sooka.system.domain.SysRole;
import com.sooka.system.mapper.SysDeptMapper;
import com.sooka.system.mapper.SysMenuMapper;
import com.sooka.system.service.ISysDeptService;
import org.apache.commons.lang3.ArrayUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.sooka.common.annotation.DataScope;
import com.sooka.common.constant.UserConstants;
import com.sooka.common.core.domain.Ztree;
import com.sooka.common.exception.BusinessException;
import com.sooka.common.utils.StringUtils;

import javax.annotation.Resource;

/**
 * 部门管理 服务实现
 * 
 * @author lei_wang
 */
@Service
public class SysDeptServiceImpl implements ISysDeptService
{
    @Resource
    private SysDeptMapper deptMapper;
    @Resource
    private SysMenuMapper menuMapper;

    /**
     * 查询部门管理数据
     * 
     * @param dept 部门信息
     * @return 部门信息集合
     */
    @Override
    @DataScope(deptAlias = "d")
    public List<SysDept> selectDeptList(SysDept dept)
    {
        return deptMapper.selectDeptList(dept);
    }

    /**
     * 查询部门管理树
     * 
     * @param dept 部门信息
     * @return 所有部门信息
     */
    @Override
    @DataScope(deptAlias = "d")
    public List<Ztree> selectDeptTree(SysDept dept)
    {
        List<SysDept> deptList = deptMapper.selectDeptList(dept);
        List<Ztree> ztrees = initZtree(deptList);
        return ztrees;
    }

    /**
     * 查询部门管理树
     *
     * @param shareType 共享类型
     * @return 所有部门信息
     */
    @Override
//    @DataScope(deptAlias = "d")
    public List<Ztree> selectProvideDeptTree(String shareType)
    {
        List<SysDept> deptList = deptMapper.selectProvideDeptList(shareType);
        List<Ztree> ztrees = initZtree(deptList);
        return ztrees;
    }

    /**
     * 查询部门管理树
     *
     * @param shareType 共享类型
     * @return 所有部门信息
     */
    @Override
    public List<Ztree> selectProvideDeptDataTree(String shareType)
    {
        sysMenuList = new ArrayList();
        List<SysMenu> list = menuMapper.selectMenuNormalAll();
        Long menuId = 0L;
        switch (shareType){
            case "share_type_1"://市共享数据核验管理
                menuId = 2089L;
                break;
            case "share_type_4":
                menuId = 2088L;//省共享数据核验管理
                break;
        }
        getSysMenuListByParentId(menuId, list);
        for (int m = 0; m < list.size(); m++) {
            if(String.valueOf(list.get(m).getMenuId()).equals(String.valueOf(menuId))){
                sysMenuList.add(list.get(m));
            }
        }
        List<SysDept> deptList = new ArrayList();
        for (int m = 0; m < sysMenuList.size(); m++) {
            SysMenu menu = sysMenuList.get(m);
            SysDept dept = new SysDept();
            dept.setStatus("2");
            dept.setDeptId(menu.getMenuId());
            dept.setDeptName(menu.getMenuName());
            dept.setParentId(menu.getParentId());
            deptList.add(dept);
        }
        List<SysDept> deptChildList = new ArrayList();
        for (int i = 0; i < deptList.size(); i++) {
            deptChildList.add(deptList.get(i));
        }
        //只选择到倒数第二层节点 排除根节点
        for (int i = 0; i < deptList.size(); i++) {
            for (int j = 0; j < deptChildList.size(); j++) {
                if(String.valueOf(deptList.get(i).getDeptId()).equals(String.valueOf(deptChildList.get(j).getParentId()))){
                    deptList.get(i).setStatus("0");
                    break;
                }
            }
        }
        for (int i = 0; i < deptList.size(); i++) {
            if(deptList.get(i).getStatus().equals("2")){
                deptList.remove(i--);
            }
        }
//        List<SysDept> deptList = deptMapper.selectProvideDeptDataList(shareType);//2088 省共享数据核验管理 2089 市共享数据核验管理
        List<Ztree> ztrees = initZtree(deptList);
        return ztrees;
    }
    List<SysMenu> sysMenuList = new ArrayList();
    private void getSysMenuListByParentId(Long parentId, List<SysMenu> menuList){
        for (int m = 0; m < menuList.size(); m++) {
            SysMenu menu = menuList.get(m);
            if(String.valueOf(menu.getParentId()).equals(String.valueOf(parentId))){
                sysMenuList.add(menu);
                getSysMenuListByParentId(menu.getMenuId(), menuList);
            }
        }
    }


    /**
     * 查询部门管理树（排除下级）
     * 
     * @param deptId 部门ID
     * @return 所有部门信息
     */
    @Override
    @DataScope(deptAlias = "d")
    public List<Ztree> selectDeptTreeExcludeChild(SysDept dept)
    {
        Long deptId = dept.getDeptId();
        List<SysDept> deptList = deptMapper.selectDeptList(dept);
        Iterator<SysDept> it = deptList.iterator();
        while (it.hasNext())
        {
            SysDept d = (SysDept) it.next();
            if (d.getDeptId().intValue() == deptId
                    || ArrayUtils.contains(StringUtils.split(d.getAncestors(), ","), deptId + ""))
            {
                it.remove();
            }
        }
        List<Ztree> ztrees = initZtree(deptList);
        return ztrees;
    }

    /**
     * 根据角色ID查询部门（数据权限）
     *
     * @param role 角色对象
     * @return 部门列表（数据权限）
     */
    @Override
    public List<Ztree> roleDeptTreeData(SysRole role)
    {
        Long roleId = role.getRoleId();
        List<Ztree> ztrees = new ArrayList<Ztree>();
        List<SysDept> deptList = selectDeptList(new SysDept());
        if (StringUtils.isNotNull(roleId))
        {
            List<String> roleDeptList = deptMapper.selectRoleDeptTree(roleId);
            ztrees = initZtree(deptList, roleDeptList);
        }
        else
        {
            ztrees = initZtree(deptList);
        }
        return ztrees;
    }

    /**
     * 对象转部门树
     *
     * @param deptList 部门列表
     * @return 树结构列表
     */
    public List<Ztree> initZtree(List<SysDept> deptList)
    {
        return initZtree(deptList, null);
    }

    /**
     * 对象转部门树
     *
     * @param deptList 部门列表
     * @param roleDeptList 角色已存在菜单列表
     * @return 树结构列表
     */
    public List<Ztree> initZtree(List<SysDept> deptList, List<String> roleDeptList)
    {

        List<Ztree> ztrees = new ArrayList<Ztree>();
        boolean isCheck = StringUtils.isNotNull(roleDeptList);
        for (SysDept dept : deptList)
        {
            if (UserConstants.DEPT_NORMAL.equals(dept.getStatus()))
            {
                Ztree ztree = new Ztree();
                ztree.setId(dept.getDeptId());
                ztree.setpId(dept.getParentId());
                ztree.setName(dept.getDeptName());
                ztree.setTitle(dept.getDeptName());
                if (isCheck)
                {
                    ztree.setChecked(roleDeptList.contains(dept.getDeptId() + dept.getDeptName()));
                }
                ztrees.add(ztree);
            }
        }
        return ztrees;
    }

    /**
     * 查询部门人数
     * 
     * @param parentId 部门ID
     * @return 结果
     */
    @Override
    public int selectDeptCount(Long parentId)
    {
        SysDept dept = new SysDept();
        dept.setParentId(parentId);
        return deptMapper.selectDeptCount(dept);
    }

    /**
     * 查询部门是否存在用户
     * 
     * @param deptId 部门ID
     * @return 结果 true 存在 false 不存在
     */
    @Override
    public boolean checkDeptExistUser(Long deptId)
    {
        int result = deptMapper.checkDeptExistUser(deptId);
        return result > 0 ? true : false;
    }

    /**
     * 删除部门管理信息
     * 
     * @param deptId 部门ID
     * @return 结果
     */
    @Override
    public int deleteDeptById(Long deptId)
    {
        return deptMapper.deleteDeptById(deptId);
    }

    /**
     * 新增保存部门信息
     * 
     * @param dept 部门信息
     * @return 结果
     */
    @Override
    public int insertDept(SysDept dept)
    {
        SysDept info = deptMapper.selectDeptById(dept.getParentId());
        // 如果父节点不为"正常"状态,则不允许新增子节点
        if (!UserConstants.DEPT_NORMAL.equals(info.getStatus()))
        {
            throw new BusinessException("部门停用，不允许新增");
        }
        dept.setAncestors(info.getAncestors() + "," + dept.getParentId());
        return deptMapper.insertDept(dept);
    }

    /**
     * 修改保存部门信息
     * 
     * @param dept 部门信息
     * @return 结果
     */
    @Override
    @Transactional
    public int updateDept(SysDept dept)
    {
        SysDept newParentDept = deptMapper.selectDeptById(dept.getParentId());
        SysDept oldDept = selectDeptById(dept.getDeptId());
        if (StringUtils.isNotNull(newParentDept) && StringUtils.isNotNull(oldDept))
        {
            String newAncestors = newParentDept.getAncestors() + "," + newParentDept.getDeptId();
            String oldAncestors = oldDept.getAncestors();
            dept.setAncestors(newAncestors);
            updateDeptChildren(dept.getDeptId(), newAncestors, oldAncestors);
        }
        int result = deptMapper.updateDept(dept);
        if (UserConstants.DEPT_NORMAL.equals(dept.getStatus()))
        {
            // 如果该部门是启用状态，则启用该部门的所有上级部门
            updateParentDeptStatus(dept);
        }
        return result;
    }

    /**
     * 修改该部门的父级部门状态
     * 
     * @param dept 当前部门
     */
    private void updateParentDeptStatus(SysDept dept)
    {
        String updateBy = dept.getUpdateBy();
        dept = deptMapper.selectDeptById(dept.getDeptId());
        dept.setUpdateBy(updateBy);
        deptMapper.updateDeptStatus(dept);
    }

    /**
     * 修改子元素关系
     * 
     * @param deptId 被修改的部门ID
     * @param newAncestors 新的父ID集合
     * @param oldAncestors 旧的父ID集合
     */
    public void updateDeptChildren(Long deptId, String newAncestors, String oldAncestors)
    {
        List<SysDept> children = deptMapper.selectChildrenDeptById(deptId);
        for (SysDept child : children)
        {
            child.setAncestors(child.getAncestors().replace(oldAncestors, newAncestors));
        }
        if (children.size() > 0)
        {
            deptMapper.updateDeptChildren(children);
        }
    }

    /**
     * 根据部门ID查询信息
     * 
     * @param deptId 部门ID
     * @return 部门信息
     */
    @Override
    public SysDept selectDeptById(Long deptId)
    {
        return deptMapper.selectDeptById(deptId);
    }

    /**
     * 根据ID查询所有子部门（正常状态）
     * 
     * @param deptId 部门ID
     * @return 子部门数
     */
    @Override
    public int selectNormalChildrenDeptById(Long deptId)
    {
        return deptMapper.selectNormalChildrenDeptById(deptId);
    }

    /**
     * 校验部门名称是否唯一
     * 
     * @param dept 部门信息
     * @return 结果
     */
    @Override
    public String checkDeptNameUnique(SysDept dept)
    {
        Long deptId = StringUtils.isNull(dept.getDeptId()) ? -1L : dept.getDeptId();
        SysDept info = deptMapper.checkDeptNameUnique(dept.getDeptName(), dept.getParentId());
        if (StringUtils.isNotNull(info) && info.getDeptId().longValue() != deptId.longValue())
        {
            return UserConstants.DEPT_NAME_NOT_UNIQUE;
        }
        return UserConstants.DEPT_NAME_UNIQUE;
    }
}
