package com.sooka.applyData.mapper;

import com.sooka.applyData.domain.DataDetailed;
import com.sooka.applyData.domain.DataRecord;
import org.apache.ibatis.annotations.Param;

import java.util.List;
import java.util.Map;

/**
 * 申请记录Mapper接口
 *
 * @author yhliang
 * @date 2021-07-06
 */
public interface DataRecordMapper
{
    /**
     * 查询申请记录
     *
     * @param id 申请记录ID
     * @return 申请记录
     */
    public DataRecord selectDataRecordById(String id);

    /**
     * 查询申请子表记录
     *
     * @param subId 申请子表记录ID
     * @return 申请记录
     */
    public DataDetailed selectDataRecordDetailedBySubId(String subId);

    /**
     * 根据接口ID查询子表记录
     *
     * @param intId 申请子表记录ID
     * @return 申请记录
     */
    public List<DataDetailed> selectDataDetailedByIntId(String intId);

    /**
     * 查询申请记录列表
     *
     * @param DataRecord 申请记录
     * @return 申请记录集合
     */
    public List<DataRecord> selectDataRecordList(DataRecord DataRecord);

    /**
     * 查询申请记录明细
     *
     * @param DataDetailed 查询条件
     * @return 申请明细集合
     */
    public List<DataDetailed> selectDataDetailedList(DataDetailed DataDetailed);


    /**
     * 新增申请记录
     *
     * @param DataRecord 申请记录
     * @return 结果
     */
    public int insertDataRecord(DataRecord DataRecord);

    /**
     * 新增申请明细
     *
     * @param DataDetailed 申请明细
     * @return 结果
     */
    public int insertDataDetailed(DataDetailed DataDetailed);

    /**
     * 修改申请记录
     *
     * @param intBo 申请记录
     * @return 结果
     */
    public int editDataRecord(DataRecord intBo);

    /**
     * 批量删除申请记录
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteDataRecordByIds(String[] ids);

    /**
     * 批量删除申请明细
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteDataDetailedByRecordIds(String[] ids);

    /**
     * 批量新增申请明细
     *
     * @param DataDetailedList 申请明细列表
     * @return 结果
     */
    public int batchDataDetailed(List<DataDetailed> DataDetailedList);

    /**
     * 状态修改
     *
     * @param DataDetailed 接口信息
     * @return 结果
     */
    public int changeStatus(DataDetailed DataDetailed);

    /**
     * 提交审核
     * @return 结果
     */
    public int updateStatus(@Param("id") String id, @Param("status") String status);

    /**
     * 接口申请频次
     * @param shareTypes 接口类型
     * @return 结果
     */
    public Map applyFrequency(String[] shareTypes);

    /**
     * 接口申请数量
     * @param provideDeptId 提供部门ID
     * @return 结果
     */
    public Map applyCount(@Param("year") String year, @Param("provideDeptId") String provideDeptId);



}
