package com.sooka.applyData.service;


import com.sooka.applyData.domain.DataDetailed;
import com.sooka.applyData.domain.DataRecord;

import java.util.List;

/**
 * 申请记录Service接口
 *
 * @author yhliang
 * @date 2021-07-06
 */
public interface IDataRecordService
{
    /**
     * 查询申请记录
     *
     * @param id 申请记录ID
     * @return 申请记录
     */
    public DataRecord selectDataRecordById(String id);

    /**
     * 查询申请子表记录
     *
     * @param subId 申请子表记录ID
     * @return 申请记录
     */
    public DataDetailed selectDataRecordDetailedBySubId(String subId);

    /**
     * 查询申请记录列表
     *
     * @param DataRecord 申请记录
     * @return 申请记录集合
     */
    public List<DataRecord> selectDataRecordList(DataRecord DataRecord);

    /**
     * 查询申请记录明细
     *
     * @param DataDetailed 查询条件
     * @return 申请明细集合
     */
    public List<DataDetailed> selectDataDetailedList(DataDetailed DataDetailed);

    /**
     * 新增申请记录
     *
     * @param intBo 申请记录
     * @return 结果
     */
    public int insertDataRecord(DataRecord intBo);

    /**
     * 修改申请记录
     *
     * @param intBo 申请记录
     * @return 结果
     */
    public int editDataRecord(DataRecord intBo);

    /**
     * 保存驳回信息字段
     */
    public int rejectDataRecord(DataRecord intBo);

    /**
     * 批量删除申请记录
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteDataRecordByIds(String ids);

    /**
     * 状态修改
     *
     * @param DataDetailed 接口信息
     * @return 结果
     */
    public int changeStatus(DataDetailed DataDetailed);

    /**
     * 提交审核
     * @return 结果
     */
    public int updateStatus(String id, String status);

    /**
     * 接口申请频次
     * @param shareTypes 接口类型
     * @return 结果
     */
    public String[] applyFrequency(String[] shareTypes);

    /**
     * 接口申请数量
     * @param deptId 部门ID
     * @return 结果
     */
    public String[] applyCount(String year, String deptId);

}
