package com.sooka.system.gas.aofe_meter_reading_infor.service.impl;

import com.sooka.common.core.text.Convert;
import com.sooka.common.utils.DateUtils;
import com.sooka.framework.util.ShiroUtils;
import com.sooka.system.gas.aofe_meter_reading_infor.domain.TGuijiAofeMeterReadingInfor;
import com.sooka.system.gas.aofe_meter_reading_infor.mapper.TGuijiAofeMeterReadingMapper;
import com.sooka.system.gas.aofe_meter_reading_infor.service.ITGuijiAofeMeterReadingInforService;
import com.sooka.system.service.impl.Guiji_Base_Service;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 奥枫收费系统-抄表信息Service业务层处理
 *
 * @author lei
 * @date 2022-08-22
 */
@Service
public class TGuijiAofeMeterReadingInforServiceImpl extends Guiji_Base_Service implements ITGuijiAofeMeterReadingInforService
{
    @Resource
    private TGuijiAofeMeterReadingMapper mapper;

    /**
     * 查询奥枫收费系统-抄表信息
     *
     * @param id 奥枫收费系统-抄表信息ID
     * @return 奥枫收费系统-抄表信息
     */
    @Override
    public TGuijiAofeMeterReadingInfor selectById(String id)
    {
        return mapper.selectById(id);
    }

    /**
     * 查询奥枫收费系统-抄表信息列表
     *
     * @param param 奥枫收费系统-抄表信息
     * @return 奥枫收费系统-抄表信息
     */
    @Override
    public List<TGuijiAofeMeterReadingInfor> selectList(TGuijiAofeMeterReadingInfor param)
    {
        List<TGuijiAofeMeterReadingInfor> list = mapper.selectList(param);
        param.setOperationStatus(1L);
        param.setParam(param.toString());
        param.setInterfacetype("platform_interfacetype_1");//1 共享 2归集
        param.setInterfaceinfoId("b8b63daa-86af-41b0-af10-6d78f77898ca");
        param.setInterfaceinfoName("共享（市）-奥枫收费系统-抄表信息");
        Long deptId = ShiroUtils.getSysUser().getDept().getDeptId();
        String deptName = ShiroUtils.getSysUser().getDept().getDeptName();
        param.setDeptId(deptId);
        param.setDeptName(deptName);
        add_log(param);
        return list;
    }

    /**
     * 新增奥枫收费系统-抄表信息
     *
     * @param param 奥枫收费系统-抄表信息
     * @return 结果
     */
    @Override
    public int insert(TGuijiAofeMeterReadingInfor param)
    {
        param.setCreateTime(DateUtils.getNowDate());
        return mapper.insert(param);
    }

    /**
     * 修改奥枫收费系统-抄表信息
     *
     * @param param 奥枫收费系统-抄表信息
     * @return 结果
     */
    @Override
    public int update(TGuijiAofeMeterReadingInfor param)
    {
        return mapper.update(param);
    }

    /**
     * 删除奥枫收费系统-抄表信息对象
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteByIds(String ids)
    {
        return mapper.deleteByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除奥枫收费系统-抄表信息信息
     *
     * @param id 奥枫收费系统-抄表信息ID
     * @return 结果
     */
    @Override
    public int deleteById(String id)
    {
        return mapper.deleteById(id);
    }
}
