package com.sooka.system.gas.aofe_user_infor.service.impl;

import com.sooka.common.core.text.Convert;
import com.sooka.common.utils.DateUtils;
import com.sooka.framework.util.ShiroUtils;
import com.sooka.system.gas.aofe_user_infor.domain.TGuijiAofeUserInfor;
import com.sooka.system.gas.aofe_user_infor.mapper.TGuijiAofeUserInforMapper;
import com.sooka.system.gas.aofe_user_infor.service.ITGuijiAofeUserInforService;
import com.sooka.system.service.impl.Guiji_Base_Service;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 奥枫收费系统-用户信息Service业务层处理
 *
 * @author lei
 * @date 2022-08-22
 */
@Service
public class TGuijiAofeUserInforServiceImpl extends Guiji_Base_Service implements ITGuijiAofeUserInforService
{
    @Resource
    private TGuijiAofeUserInforMapper mapper;

    /**
     * 查询奥枫收费系统-用户信息
     *
     * @param id 奥枫收费系统-用户信息ID
     * @return 奥枫收费系统-用户信息
     */
    @Override
    public TGuijiAofeUserInfor selectById(String id)
    {
        return mapper.selectById(id);
    }

    /**
     * 查询奥枫收费系统-用户信息列表
     *
     * @param param 奥枫收费系统-用户信息
     * @return 奥枫收费系统-用户信息
     */
    @Override
    public List<TGuijiAofeUserInfor> selectList(TGuijiAofeUserInfor param)
    {
        List<TGuijiAofeUserInfor> list = mapper.selectList(param);
        param.setOperationStatus(1L);
        param.setParam(param.toString());
        param.setInterfacetype("platform_interfacetype_1");//1 共享 2归集
        param.setInterfaceinfoId("2ea17316-a950-4815-86f0-d4df011c8692");
        param.setInterfaceinfoName("共享（市）-奥枫收费系统-用户信息");
        Long deptId = ShiroUtils.getSysUser().getDept().getDeptId();
        String deptName = ShiroUtils.getSysUser().getDept().getDeptName();
        param.setDeptId(deptId);
        param.setDeptName(deptName);
        add_log(param);
        return list;
    }

    /**
     * 新增奥枫收费系统-用户信息
     *
     * @param param 奥枫收费系统-用户信息
     * @return 结果
     */
    @Override
    public int insert(TGuijiAofeUserInfor param)
    {
        param.setCreateTime(DateUtils.getNowDate());
        return mapper.insert(param);
    }

    /**
     * 修改奥枫收费系统-用户信息
     *
     * @param param 奥枫收费系统-用户信息
     * @return 结果
     */
    @Override
    public int update(TGuijiAofeUserInfor param)
    {
        return mapper.update(param);
    }

    /**
     * 删除奥枫收费系统-用户信息对象
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteByIds(String ids)
    {
        return mapper.deleteByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除奥枫收费系统-用户信息信息
     *
     * @param id 奥枫收费系统-用户信息ID
     * @return 结果
     */
    @Override
    public int deleteById(String id)
    {
        return mapper.deleteById(id);
    }
}
