package com.sooka.system.gas.sc_meter_reading_infor.service.impl;

import com.sooka.common.core.text.Convert;
import com.sooka.common.utils.DateUtils;
import com.sooka.framework.util.ShiroUtils;
import com.sooka.system.gas.sc_meter_reading_infor.domain.TGuijiSCMeterReadingInfor;
import com.sooka.system.gas.sc_meter_reading_infor.mapper.TGuijiSCMeterReadingMapper;
import com.sooka.system.gas.sc_meter_reading_infor.service.ITGuijiSCMeterReadingInforService;
import com.sooka.system.service.impl.Guiji_Base_Service;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 思凯收费系统-抄表信息Service业务层处理
 *
 * @author lei
 * @date 2022-08-22
 */
@Service
public class TGuijiSCMeterReadingInforServiceImpl extends Guiji_Base_Service implements ITGuijiSCMeterReadingInforService
{
    @Resource
    private TGuijiSCMeterReadingMapper mapper;

    /**
     * 查询思凯收费系统-抄表信息
     *
     * @param id 思凯收费系统-抄表信息ID
     * @return 思凯收费系统-抄表信息
     */
    @Override
    public TGuijiSCMeterReadingInfor selectById(String id)
    {
        return mapper.selectById(id);
    }

    /**
     * 查询思凯收费系统-抄表信息列表
     *
     * @param param 思凯收费系统-抄表信息
     * @return 思凯收费系统-抄表信息
     */
    @Override
    public List<TGuijiSCMeterReadingInfor> selectList(TGuijiSCMeterReadingInfor param)
    {
        List<TGuijiSCMeterReadingInfor> list = mapper.selectList(param);
        param.setOperationStatus(1L);
        param.setParam(param.toString());
        param.setInterfacetype("platform_interfacetype_1");//1 共享 2归集
        param.setInterfaceinfoId("445bb69b-8934-4ae8-96ca-c950a4e0f3bc");
        param.setInterfaceinfoName("共享（市）-思凯收费系统-抄表信息");
        Long deptId = ShiroUtils.getSysUser().getDept().getDeptId();
        String deptName = ShiroUtils.getSysUser().getDept().getDeptName();
        param.setDeptId(deptId);
        param.setDeptName(deptName);
        add_log(param);
        return list;
    }

    /**
     * 新增思凯收费系统-抄表信息
     *
     * @param param 思凯收费系统-抄表信息
     * @return 结果
     */
    @Override
    public int insert(TGuijiSCMeterReadingInfor param)
    {
        param.setCreateTime(DateUtils.getNowDate());
        return mapper.insert(param);
    }

    /**
     * 修改思凯收费系统-抄表信息
     *
     * @param param 思凯收费系统-抄表信息
     * @return 结果
     */
    @Override
    public int update(TGuijiSCMeterReadingInfor param)
    {
        return mapper.update(param);
    }

    /**
     * 删除思凯收费系统-抄表信息对象
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteByIds(String ids)
    {
        return mapper.deleteByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除思凯收费系统-抄表信息信息
     *
     * @param id 思凯收费系统-抄表信息ID
     * @return 结果
     */
    @Override
    public int deleteById(String id)
    {
        return mapper.deleteById(id);
    }
}
