package com.sooka.system.gas.sc_user_infor.service.impl;

import com.sooka.common.core.text.Convert;
import com.sooka.common.utils.DateUtils;
import com.sooka.framework.util.ShiroUtils;
import com.sooka.system.gas.sc_user_infor.domain.TGuijiSCUserInfor;
import com.sooka.system.gas.sc_user_infor.mapper.TGuijiSCUserInforMapper;
import com.sooka.system.gas.sc_user_infor.service.ITGuijiSCUserInforService;
import com.sooka.system.service.impl.Guiji_Base_Service;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 思凯收费系统-用户信息Service业务层处理
 *
 * @author lei
 * @date 2022-08-22
 */
@Service
public class TGuijiSCUserInforServiceImpl extends Guiji_Base_Service implements ITGuijiSCUserInforService
{
    @Resource
    private TGuijiSCUserInforMapper mapper;

    /**
     * 查询思凯收费系统-用户信息
     *
     * @param id 思凯收费系统-用户信息ID
     * @return 思凯收费系统-用户信息
     */
    @Override
    public TGuijiSCUserInfor selectById(String id)
    {
        return mapper.selectById(id);
    }

    /**
     * 查询思凯收费系统-用户信息列表
     *
     * @param param 思凯收费系统-用户信息
     * @return 思凯收费系统-用户信息
     */
    @Override
    public List<TGuijiSCUserInfor> selectList(TGuijiSCUserInfor param)
    {
        List<TGuijiSCUserInfor> list = mapper.selectList(param);
        param.setOperationStatus(1L);
        param.setParam(param.toString());
        param.setInterfacetype("platform_interfacetype_1");//1 共享 2归集
        param.setInterfaceinfoId("d82ce143-5cc5-4890-9397-774da532580c");
        param.setInterfaceinfoName("共享（市）-思凯收费系统-用户信息");
        Long deptId = ShiroUtils.getSysUser().getDept().getDeptId();
        String deptName = ShiroUtils.getSysUser().getDept().getDeptName();
        param.setDeptId(deptId);
        param.setDeptName(deptName);
        add_log(param);
        return list;
    }

    /**
     * 新增思凯收费系统-用户信息
     *
     * @param param 思凯收费系统-用户信息
     * @return 结果
     */
    @Override
    public int insert(TGuijiSCUserInfor param)
    {
        param.setCreateTime(DateUtils.getNowDate());
        return mapper.insert(param);
    }

    /**
     * 修改思凯收费系统-用户信息
     *
     * @param param 思凯收费系统-用户信息
     * @return 结果
     */
    @Override
    public int update(TGuijiSCUserInfor param)
    {
        return mapper.update(param);
    }

    /**
     * 删除思凯收费系统-用户信息对象
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteByIds(String ids)
    {
        return mapper.deleteByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除思凯收费系统-用户信息信息
     *
     * @param id 思凯收费系统-用户信息ID
     * @return 结果
     */
    @Override
    public int deleteById(String id)
    {
        return mapper.deleteById(id);
    }
}
