package com.sooka.system.gas.zenner_user_infor.service.impl;

import com.sooka.common.core.text.Convert;
import com.sooka.common.utils.DateUtils;
import com.sooka.framework.util.ShiroUtils;
import com.sooka.system.gas.zenner_user_infor.domain.TGuijiZennerUserInfor;
import com.sooka.system.gas.zenner_user_infor.mapper.TGuijiZennerUserInforMapper;
import com.sooka.system.gas.zenner_user_infor.service.ITGuijiZennerUserInforService;
import com.sooka.system.service.impl.Guiji_Base_Service;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 真兰收费系统-用户信息Service业务层处理
 *
 * @author lei
 * @date 2022-08-22
 */
@Service
public class TGuijiZennerUserInforServiceImpl extends Guiji_Base_Service implements ITGuijiZennerUserInforService
{
    @Resource
    private TGuijiZennerUserInforMapper mapper;

    /**
     * 查询真兰收费系统-用户信息
     *
     * @param id 真兰收费系统-用户信息ID
     * @return 真兰收费系统-用户信息
     */
    @Override
    public TGuijiZennerUserInfor selectById(String id)
    {
        return mapper.selectById(id);
    }

    /**
     * 查询真兰收费系统-用户信息列表
     *
     * @param param 真兰收费系统-用户信息
     * @return 真兰收费系统-用户信息
     */
    @Override
    public List<TGuijiZennerUserInfor> selectList(TGuijiZennerUserInfor param)
    {
        List<TGuijiZennerUserInfor> list = mapper.selectList(param);
        param.setOperationStatus(1L);
        param.setParam(param.toString());
        param.setInterfacetype("platform_interfacetype_1");//1 共享 2归集
        param.setInterfaceinfoId("dc29f31a-17e3-4747-a3ed-acc5d3915b46");
        param.setInterfaceinfoName("共享（市）-真兰收费系统-用户信息");
        Long deptId = ShiroUtils.getSysUser().getDept().getDeptId();
        String deptName = ShiroUtils.getSysUser().getDept().getDeptName();
        param.setDeptId(deptId);
        param.setDeptName(deptName);
        add_log(param);
        return list;
    }

    /**
     * 新增真兰收费系统-用户信息
     *
     * @param param 真兰收费系统-用户信息
     * @return 结果
     */
    @Override
    public int insert(TGuijiZennerUserInfor param)
    {
        param.setCreateTime(DateUtils.getNowDate());
        return mapper.insert(param);
    }

    /**
     * 修改真兰收费系统-用户信息
     *
     * @param param 真兰收费系统-用户信息
     * @return 结果
     */
    @Override
    public int update(TGuijiZennerUserInfor param)
    {
        return mapper.update(param);
    }

    /**
     * 删除真兰收费系统-用户信息对象
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteByIds(String ids)
    {
        return mapper.deleteByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除真兰收费系统-用户信息信息
     *
     * @param id 真兰收费系统-用户信息ID
     * @return 结果
     */
    @Override
    public int deleteById(String id)
    {
        return mapper.deleteById(id);
    }
}
