package com.sooka.system.real_estate.on_sale_record_change.service.impl;

import com.sooka.common.core.text.Convert;
import com.sooka.common.utils.DateUtils;
import com.sooka.framework.util.ShiroUtils;
import com.sooka.system.real_estate.on_sale_record_change.domain.TGuijiRealEstateOnSaleRecordChange;
import com.sooka.system.real_estate.on_sale_record_change.mapper.TGuijiRealEstateOnSaleRecordChangeMapper;
import com.sooka.system.real_estate.on_sale_record_change.service.ITGuijiRealEstateOnSaleRecordChangeService;
import com.sooka.system.service.impl.Guiji_Base_Service;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 市房地产-现售备案变更信息Service业务层处理
 *
 * @author lei
 * @date 2022-08-22
 */
@Service
public class TGuijiRealEstateOnSaleRecordChangeServiceImpl extends Guiji_Base_Service implements ITGuijiRealEstateOnSaleRecordChangeService
{
    @Resource
    private TGuijiRealEstateOnSaleRecordChangeMapper mapper;

    /**
     * 查询市房地产-现售备案变更信息
     *
     * @param id 市房地产-现售备案变更信息ID
     * @return 市房地产-现售备案变更信息
     */
    @Override
    public TGuijiRealEstateOnSaleRecordChange selectById(String id)
    {
        return mapper.selectById(id);
    }

    /**
     * 查询市房地产-现售备案变更信息列表
     *
     * @param param 市房地产-现售备案变更信息
     * @return 市房地产-现售备案变更信息
     */
    @Override
    public List<TGuijiRealEstateOnSaleRecordChange> selectList(TGuijiRealEstateOnSaleRecordChange param)
    {
        List<TGuijiRealEstateOnSaleRecordChange> list = mapper.selectList(param);
        param.setOperationStatus(1L);
        param.setParam(param.toString());
        param.setInterfacetype("platform_interfacetype_1");//1 共享 2归集
        param.setInterfaceinfoId("93cfb65e-9a83-47a2-a588-2517e9c57365");
        param.setInterfaceinfoName("共享（市）-市房地产-现售备案变更信息");
        Long deptId = ShiroUtils.getSysUser().getDept().getDeptId();
        String deptName = ShiroUtils.getSysUser().getDept().getDeptName();
        param.setDeptId(deptId);
        param.setDeptName(deptName);
        add_log(param);
        return list;
    }

    /**
     * 新增市房地产-现售备案变更信息
     *
     * @param param 市房地产-现售备案变更信息
     * @return 结果
     */
    @Override
    public int insert(TGuijiRealEstateOnSaleRecordChange param)
    {
        param.setCreateTime(DateUtils.getNowDate());
        return mapper.insert(param);
    }

    /**
     * 修改市房地产-现售备案变更信息
     *
     * @param param 市房地产-现售备案变更信息
     * @return 结果
     */
    @Override
    public int update(TGuijiRealEstateOnSaleRecordChange param)
    {
        return mapper.update(param);
    }

    /**
     * 删除市房地产-现售备案变更信息对象
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteByIds(String ids)
    {
        return mapper.deleteByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除市房地产-现售备案变更信息信息
     *
     * @param id 市房地产-现售备案变更信息ID
     * @return 结果
     */
    @Override
    public int deleteById(String id)
    {
        return mapper.deleteById(id);
    }
}
