package com.sooka.system.real_estate.pre_order_cancel_notice.service.impl;

import com.sooka.common.core.text.Convert;
import com.sooka.common.utils.DateUtils;
import com.sooka.framework.util.ShiroUtils;
import com.sooka.system.real_estate.pre_order_cancel_notice.domain.TGuijiRealEstatePreOrderCancelNotice;
import com.sooka.system.real_estate.pre_order_cancel_notice.mapper.TGuijiRealEstatePreOrderCancelNoticeMapper;
import com.sooka.system.real_estate.pre_order_cancel_notice.service.ITGuijiRealEstatePreOrderCancelNoticeService;
import com.sooka.system.service.impl.Guiji_Base_Service;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 市房地产-预购商品房预告注销信息Service业务层处理
 *
 * @author lei
 * @date 2022-08-22
 */
@Service
public class TGuijiRealEstatePreOrderCancelNoticeServiceImpl extends Guiji_Base_Service implements ITGuijiRealEstatePreOrderCancelNoticeService
{
    @Resource
    private TGuijiRealEstatePreOrderCancelNoticeMapper mapper;

    /**
     * 查询市房地产-预购商品房预告注销信息
     *
     * @param id 市房地产-预购商品房预告注销信息ID
     * @return 市房地产-预购商品房预告注销信息
     */
    @Override
    public TGuijiRealEstatePreOrderCancelNotice selectById(String id)
    {
        return mapper.selectById(id);
    }

    /**
     * 查询市房地产-预购商品房预告注销信息列表
     *
     * @param param 市房地产-预购商品房预告注销信息
     * @return 市房地产-预购商品房预告注销信息
     */
    @Override
    public List<TGuijiRealEstatePreOrderCancelNotice> selectList(TGuijiRealEstatePreOrderCancelNotice param)
    {
        List<TGuijiRealEstatePreOrderCancelNotice> list = mapper.selectList(param);
        param.setOperationStatus(1L);
        param.setParam(param.toString());
        param.setInterfacetype("platform_interfacetype_1");//1 共享 2归集
        param.setInterfaceinfoId("4de6849b-a641-48be-ba9e-95b579e9c06d");
        param.setInterfaceinfoName("共享（市）-市房地产-预购商品房预告注销信息");
        Long deptId = ShiroUtils.getSysUser().getDept().getDeptId();
        String deptName = ShiroUtils.getSysUser().getDept().getDeptName();
        param.setDeptId(deptId);
        param.setDeptName(deptName);
        add_log(param);
        return list;
    }

    /**
     * 新增市房地产-预购商品房预告注销信息
     *
     * @param param 市房地产-预购商品房预告注销信息
     * @return 结果
     */
    @Override
    public int insert(TGuijiRealEstatePreOrderCancelNotice param)
    {
        param.setCreateTime(DateUtils.getNowDate());
        return mapper.insert(param);
    }

    /**
     * 修改市房地产-预购商品房预告注销信息
     *
     * @param param 市房地产-预购商品房预告注销信息
     * @return 结果
     */
    @Override
    public int update(TGuijiRealEstatePreOrderCancelNotice param)
    {
        return mapper.update(param);
    }

    /**
     * 删除市房地产-预购商品房预告注销信息对象
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteByIds(String ids)
    {
        return mapper.deleteByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除市房地产-预购商品房预告注销信息信息
     *
     * @param id 市房地产-预购商品房预告注销信息ID
     * @return 结果
     */
    @Override
    public int deleteById(String id)
    {
        return mapper.deleteById(id);
    }
}
